==> v0.4.78.zip: submit-social-housing-lettings-and-sales-data/app/services/exports/user_export_service.rb <==
module Exports
  class UserExportService < Exports::XmlExportService
    include Exports::UserExportConstants
    include CollectionTimeHelper

    def export_xml_users(full_update: false)
      collection = "users"
      recent_export = Export.where(collection:).order("started_at").last

      base_number = Export.where(empty_export: false, collection:).maximum(:base_number) || 1
      export = build_export_run(collection, base_number, full_update)
      archives_for_manifest = write_export_archive(export, collection, recent_export, full_update)

      export.empty_export = archives_for_manifest.empty?
      export.save!

      archives_for_manifest
    end

  private

    def get_archive_name(collection, base_number, increment)
      return unless collection

      base_number_str = "f#{base_number.to_s.rjust(4, '0')}"
      increment_str = "inc#{increment.to_s.rjust(4, '0')}"
      "#{collection}_2024_2025_apr_mar_#{base_number_str}_#{increment_str}".downcase
    end

    def retrieve_resources(recent_export, full_update, _collection)
      if !full_update && recent_export
        params = { from: recent_export.started_at, to: @start_time }
        User.where("(updated_at >= :from AND updated_at <= :to)", params)
      else
        params = { to: @start_time }
        User.where("updated_at <= :to", params)
      end
    end

    def build_export_xml(users)
      doc = Nokogiri::XML("<forms/>")

      users.each do |user|
        attribute_hash = apply_cds_transformation(user)
        form = doc.create_element("form")
        doc.at("forms") << form
        attribute_hash.each do |key, value|
          if !EXPORT_FIELDS.include?(key)
            next
          else
            form << doc.create_element(key, value)
          end
        end
      end

      xml_doc_to_temp_file(doc)
    end

    def apply_cds_transformation(user)
      attribute_hash = user.attributes_before_type_cast
      attribute_hash["role"] = user.role
      attribute_hash["organisation_name"] = user.organisation.name
      attribute_hash["active"] = user.active?
      attribute_hash["phone"] = [user.phone, user.phone_extension].compact.join(" ")
      attribute_hash
    end
  end
end

==> v0.5.15.zip: submit-social-housing-lettings-and-sales-data/app/services/exports/user_export_service.rb <==
module Exports
  class UserExportService < Exports::XmlExportService
    include Exports::UserExportConstants
    include CollectionTimeHelper

    def export_xml_users(full_update: false)
      collection = "users"
      recent_export = Export.users.order("started_at").last

      base_number = Export.users.where(empty_export: false).maximum(:base_number) || 1
      export = build_export_run(collection, base_number, full_update)
      archives_for_manifest = write_export_archive(export, collection, recent_export, full_update)

      export.empty_export = archives_for_manifest.empty?
      export.save!

      archives_for_manifest
    end

  private

    def get_archive_name(_year, base_number, increment)
      base_number_str = "f#{base_number.to_s.rjust(4, '0')}"
      increment_str = "inc#{increment.to_s.rjust(4, '0')}"
      "users_2024_2025_apr_mar_#{base_number_str}_#{increment_str}".downcase
    end

    def retrieve_resources(recent_export, full_update, _year)
      if !full_update && recent_export
        params = { from: recent_export.started_at, to: @start_time }
        User.where("(updated_at >= :from AND updated_at <= :to) OR (values_updated_at IS NOT NULL AND values_updated_at >= :from AND values_updated_at <= :to)", params)
      else
        params = { to: @start_time }
        User.where("updated_at <= :to", params)
      end
    end

    def build_export_xml(users)
      doc = Nokogiri::XML("<forms/>")

      users.each do |user|
        attribute_hash = apply_cds_transformation(user)
        form = doc.create_element("form")
        doc.at("forms") << form
        attribute_hash.each do |key, value|
          if !EXPORT_FIELDS.include?(key)
            next
          else
            form << doc.create_element(key, value)
          end
        end
      end

      xml_doc_to_temp_file(doc)
    end

    def apply_cds_transformation(user)
      attribute_hash = user.attributes_before_type_cast
      attribute_hash["role"] = user.role
      attribute_hash["organisation_name"] = user.organisation.name
      attribute_hash["active"] = user.active?
      attribute_hash["phone"] = [user.phone, user.phone_extension].compact.join(" ")
      attribute_hash["last_sign_in_at"] = user.last_sign_in_at&.iso8601
      attribute_hash
    end
  end
end
